from django.conf import settings # import the settings file

def block_downloads(request):
    # return the value you want as a dictionnary. you may add multiple values in there.
    return {'MEDIALOGUE_BLOCK_DOWNLOADS': settings.MEDIALOGUE_BLOCK_DOWNLOADS}



# Generated by Django 3.2.14 on 2022-07-27 17:58

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import medialogue.models
import video_encoding.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
    ]

    operations = [
        migrations.CreateModel(
            name='Album',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date_added', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date published')),
                ('title', models.CharField(max_length=250, unique=True, verbose_name='title')),
                ('slug', models.SlugField(help_text='A "slug" is a unique URL-friendly title for an object.', max_length=250, unique=True, verbose_name='title slug')),
                ('description', models.TextField(blank=True, verbose_name='description')),
                ('is_public', models.BooleanField(default=True, help_text='Public albums will be displayed in the default views.', verbose_name='is public')),
                ('sites', models.ManyToManyField(blank=True, to='sites.Site', verbose_name='sites')),
            ],
            options={
                'verbose_name': 'Album',
                'verbose_name_plural': 'Albums',
                'ordering': ['-date_added'],
                'get_latest_by': 'date_added',
            },
        ),
        migrations.CreateModel(
            name='Media',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order', models.PositiveIntegerField(db_index=True, editable=False, verbose_name='order')),
                ('date_taken', models.DateTimeField(blank=True, help_text='Date image was taken; is obtained from the image EXIF data.', null=True, verbose_name='date taken')),
                ('title', models.CharField(max_length=250, unique=True, verbose_name='title')),
                ('slug', models.SlugField(help_text='A "slug" is a unique URL-friendly title for an object.', max_length=250, unique=True, verbose_name='slug')),
                ('caption', models.TextField(blank=True, verbose_name='caption')),
                ('date_added', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date added')),
                ('is_public', models.BooleanField(default=True, help_text='Public photographs will be displayed in the default views.', verbose_name='is public')),
                ('album', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='medialogue.album')),
                ('sites', models.ManyToManyField(blank=True, to='sites.Site', verbose_name='sites')),
            ],
            options={
                'ordering': ('order',),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Photo',
            fields=[
                ('media_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='medialogue.media')),
                ('src', models.ImageField(upload_to=medialogue.models.get_storage_path, verbose_name='src')),
            ],
            options={
                'ordering': ('order',),
                'abstract': False,
            },
            bases=('medialogue.media',),
        ),
        migrations.CreateModel(
            name='Video',
            fields=[
                ('media_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='medialogue.media')),
                ('thumbnail', models.ImageField(blank=True, upload_to='')),
                ('width', models.PositiveIntegerField(editable=False, null=True)),
                ('height', models.PositiveIntegerField(editable=False, null=True)),
                ('duration', models.FloatField(editable=False, null=True)),
                ('src', video_encoding.fields.VideoField(height_field='height', upload_to='', width_field='width')),
            ],
            options={
                'ordering': ('order',),
                'abstract': False,
            },
            bases=('medialogue.media',),
        ),
    ]



import random

from django import template

from medialogue.models import Album, Photo

register = template.Library()


@register.inclusion_tag('medialogue/tags/next_in_album.html')
def next_in_album(media, album):
    return {'media': media.get_next_in_album(album)}


@register.inclusion_tag('medialogue/tags/prev_in_album.html')
def previous_in_album(media, album):
    return {'media': media.get_previous_in_album(album)}


@register.simple_tag
def cycle_lite_album(album_title, height, width):
    """Generate image tags for jquery slideshow album.
    See http://malsup.com/jquery/cycle/lite/"""
    html = ""
    first = 'class="first"'
    for p in Gallery.objects.get(title=album_title).public():
        html += u'<img src="%s" alt="%s" height="%s" width="%s" %s />' % (
            p.get_display_url(), p.title, height, width, first)
        first = None
    return html


@register.tag
def get_photo(parser, token):
    """Get a single photo from the medialogue library and return the img tag to display it.
    Takes 3 args:
    - the photo to display. This can be either the slug of a photo, or a variable that holds either a photo instance or
      a integer (photo id)
    - the photosize to use.
    - a CSS class to apply to the img tag.
    """
    try:
        # Split the contents of the tag, i.e. tag name + argument.
        tag_name, photo, photosize, css_class = token.split_contents()
    except ValueError:
        msg = '%r tag requires 3 arguments' % token.contents[0]
        raise template.TemplateSyntaxError(msg)
    return PhotoNode(photo, photosize[1:-1], css_class[1:-1])


class PhotoNode(template.Node):

    def __init__(self, photo, photosize, css_class):
        self.photo = photo
        self.photosize = photosize
        self.css_class = css_class

    def render(self, context):
        try:
            a = template.Variable(self.photo).resolve(context)
        except:
            a = self.photo
        if isinstance(a, Photo):
            p = a
        else:
            try:
                p = Photo.objects.get(slug=a)
            except Photo.DoesNotExist:
                # Ooops. Fail silently
                return None
        if not p.is_public:
            return None
        func = getattr(p, 'get_%s_url' % (self.photosize), None)
        if func is None:
            return 'A "%s" photo size has not been defined.' % (self.photosize)
        else:
            return u'<img class="%s" src="%s" alt="%s" />' % (self.css_class, func(), p.title)


@register.tag
def get_rotating_photo(parser, token):
    """Pick at random a photo from a given medialogue album and return the img tag to display it.
    Takes 3 args:
    - the album to pick a photo from. This can be either the slug of a album, or a variable that holds either a
      album instance or a album slug.
    - the photosize to use.
    - a CSS class to apply to the img tag.
    """
    try:
        # Split the contents of the tag, i.e. tag name + argument.
        tag_name, album, photosize, css_class = token.split_contents()
    except ValueError:
        msg = '%r tag requires 3 arguments' % token.contents[0]
        raise template.TemplateSyntaxError(msg)
    return PhotoGalleryNode(album, photosize[1:-1], css_class[1:-1])


class PhotoGalleryNode(template.Node):

    def __init__(self, album, photosize, css_class):
        self.album = album
        self.photosize = photosize
        self.css_class = css_class

    def render(self, context):
        try:
            a = template.resolve_variable(self.album, context)
        except:
            a = self.album
        if isinstance(a, Gallery):
            g = a
        else:
            try:
                g = Gallery.objects.get(slug=a)
            except Gallery.DoesNotExist:
                return None
        photos = g.public()
        if len(photos) > 1:
            r = random.randint(0, len(photos) - 1)
            p = photos[r]
        elif len(photos) == 1:
            p = photos[0]
        else:
            return None
        func = getattr(p, 'get_%s_url' % (self.photosize), None)
        if func is None:
            return 'A "%s" photo size has not been defined.' % (self.photosize)
        else:
            return u'<img class="%s" src="%s" alt="%s" />' % (self.css_class, func(), p.title)



import logging
logger = logging.getLogger(__name__)
from io import BytesIO
import datetime
import itertools
import magic
from PIL import Image, UnidentifiedImageError

from django import forms
from django.contrib.postgres.forms.array import SimpleArrayField
from django.contrib.sites.models import Site
from django.contrib.admin.widgets import AdminDateWidget
from django.utils.translation import gettext_lazy as _
from django.template.defaultfilters import slugify
from django.core.files.base import ContentFile
from django.conf import settings

from django_drf_filepond.api import store_upload, get_stored_upload_file_data
from django_drf_filepond.models import TemporaryUpload

from .models import Album, Video, Photo


def _generate_slug(title, obj):
    slug_candidate = slug_original = slugify(title)
    num_found = 0
    for i in itertools.count(1):
        if not obj.objects.filter(slug=slug_candidate).exists() and not Video.objects.filter(slug=slug_candidate).exists():
            break
        num_found+=1
        slug_candidate = '{}-{}'.format(slug_original, i)
    return slug_candidate, num_found

class MediaForm(forms.Form):
    description = forms.CharField(label=_('Description'),
                                  required=False,
                                 )

    is_public = forms.BooleanField(label=_('Public'),
                                   initial=True,
                                   required=False,
                                 )
    filepond = SimpleArrayField(forms.CharField(max_length=255), widget=forms.HiddenInput(),
           required=False)


    def save(self, album):
        filelist = self.cleaned_data['filepond']
        CURRENT_SITE = Site.objects.get(id=settings.SITE_ID)

        # read list of filepond IDS which we will then import
        # via store_upload from drf-filepond: https://tinyurl.com/3t3623b2
        for upload_id in filelist:
            logger.debug('Reading file "{}".'.format(upload_id))

            su = store_upload(upload_id, destination_file_path=upload_id)

            (filename, data) = get_stored_upload_file_data(su)
            if not len(data):
                logger.debug('File "{}" is empty.'.format(filename))
                continue

            media_title_root = numbered_title = album.title

            # A photo might already exist with the same slug. So it's somewhat inefficient,
            # but we loop until we find a slug that's available.
            slug, num_found = _generate_slug(media_title_root, Photo)

            if num_found > 0:
                numbered_title = "{}({})".format(media_title_root, num_found)

            file_mimetype = magic.from_buffer(data, mime=True).split('/')[0]
            if file_mimetype  == 'image':
                logger.info("image mimetype detected")
                photo = Photo(
                            title=numbered_title,
                            slug=slug,
                            is_public=self.cleaned_data['is_public'],
                        )

                photo.src = "medialogue/{}".format(upload_id)
                photo.album = album
                photo.save()
                photo.sites.add(CURRENT_SITE)
            elif file_mimetype == "video":
                logger.info("video mimetype detected")
                video = Video(title=numbered_title, slug=slug, is_public=self.cleaned_data['is_public'])
                video.src = "medialogue/{}".format(upload_id)
                video.album = album
                video.save()
                video.sites.add(CURRENT_SITE)
            else:
                logger.error('cound not process file "{}"'.format(filename))
        return album.slug

class NewAlbumForm(MediaForm):
    album_title = forms.CharField(label='Album Title', max_length=100 )

    field_order = ['album_title', 'is_public', 'description', 'filepond',]

    def clean_title(self):
        album_title = self.cleaned_data['album_title']
        if Album.objects.filter(title=album_title).exists():
            raise forms.ValidationError(_('A album with that title already exists.'))
        return album_title

    def save(self):
        CURRENT_SITE = Site.objects.get(id=settings.SITE_ID)
        slug, num_found = _generate_slug(self.cleaned_data['album_title'], Album)
        album = Album.objects.create(title=self.cleaned_data['album_title'],
                                              slug=slug,
                                              description=self.cleaned_data['description'],
                                              is_public=self.cleaned_data['is_public'])
        album.sites.add(CURRENT_SITE)
        return super(NewAlbumForm, self).save(album)

class EditAlbumForm(forms.ModelForm):
    class Meta:
        model = Album
        fields = ['title', 'description', 'is_public']



import logging
logger = logging.getLogger(__name__)

from django.db.models.signals import post_save
from django.dispatch import receiver
from django_rq import enqueue
from .models import Video
from video_encoding import tasks
from .tasks import create_thumbnail

@receiver(post_save, sender=Video)
def convert_video(sender, instance, **kwargs):
    logger.info('convert_video signal called')
    enqueue(tasks.convert_all_videos,
            instance._meta.app_label,
            instance._meta.model_name,
            instance.pk)

@receiver(post_save, sender=Video)
def thumbnail_signal(sender, instance, **kwargs):
    enqueue(create_thumbnail, instance.pk)



from django.views.generic.list import ListView
from django.views.generic.detail import DetailView
from django.shortcuts import render, get_object_or_404
from django.views.decorators.http import require_http_methods
from django.urls import reverse
from django.http import HttpResponseRedirect
from django.template.response import TemplateResponse
from .forms import NewAlbumForm, EditAlbumForm
#@TODO - refactor MediaAlbum model name to Album
from .models import Album, Video, Photo

class AlbumListView(ListView):
    queryset = Album.objects.is_public().on_site()

class AlbumDetailView(DetailView):
    queryset = Album.objects.is_public().on_site()

@require_http_methods(['GET', 'POST'])
def AlbumEditView(request, slug):
    album = get_object_or_404(Album, slug=slug)
    form = EditAlbumForm(request.POST or None, instance=album)
    if request.POST:
        if form.is_valid():
            form.save()
    return render(request, 'medialogue/album_edit.html', {'form': form, 'album': album})

class PhotoListView(ListView):
    queryset = Photo.objects.on_site().is_public()
    paginate_by = 20

class VideoListView(ListView):
    queryset = Video.objects.on_site().is_public()
    paginate_by = 20

class PhotoDetailView(DetailView):
    queryset = Photo.objects.on_site().is_public()

def querydict_to_dict(query_dict):
    # request.POST only returns the first value in a list, this grabs it all
    # Lovingly stolen from: https://tinyurl.com/h6my82s6
    data = {}
    for key in query_dict.keys():
        v = query_dict.getlist(key)
        if len(v) == 1:
            v = v[0]
        data[key] = v
    return data

@require_http_methods(['GET', 'POST'])
def NewAlbum(request):
    if request.method == 'POST':
        post_data = querydict_to_dict(request.POST)
	# Remove the blank value associated with the automatic rendering of BulkMediaForm
	# @TODO - option 1) modify filepond to add id's as a vlue in csv
	#         option 2) manually render the form and exclude filepond input
        if '' in post_data['filepond']:
            post_data['filepond'].remove('')
        form = NewAlbumForm(post_data)
        if form.is_valid():
            slug = form.save()
            return HttpResponseRedirect(reverse('medialogue:ml-album', args=[slug]))
    else:
        form = NewAlbumForm()

    return TemplateResponse(request, 'medialogue/new-album.html', {'form': form})

class VideoDetailView(DetailView):
    queryset=Video.objects.on_site().is_public()



import os
import unicodedata
from PIL import Image
from django.utils.translation import gettext_lazy as _
from django.utils.encoding import filepath_to_uri, force_str, smart_str
from django.db import models
from django.db.models.signals import post_save
from django.contrib.contenttypes.fields import GenericRelation
from django.conf import settings
from django.contrib.sites.managers import CurrentSiteManager
from django.contrib.sites.models import Site
from django.utils.timezone import now
from django.urls import reverse

from video_encoding.fields import VideoField
from video_encoding.models import Format

from ordered_model.models import OrderedModel, OrderedModelQuerySet

import logging
logger = logging.getLogger(__name__)

# Default limit for album.latest
LATEST_LIMIT = getattr(settings, 'MEDIALOGUE_GALLERY_LATEST_LIMIT', None)

# Number of random images from the album to display.
SAMPLE_SIZE = getattr(settings, 'MEDIALOGUE_GALLERY_SAMPLE_SIZE', 5)

# max_length setting for the ImageModel ImageField
IMAGE_FIELD_MAX_LENGTH = getattr(settings, 'MEDIALOGUE_IMAGE_FIELD_MAX_LENGTH', 100)

# Path to sample image
SAMPLE_IMAGE_PATH = getattr(settings, 'MEDIALOGUE_SAMPLE_IMAGE_PATH', os.path.join(
    os.path.dirname(__file__), 'res', 'sample.jpg'))

# Photologue image path relative to media root
MEDIALOGUE_DIR = getattr(settings, 'MEDIALOGUE_DIR', 'medialogue')

# Look for user function to define file paths
MEDIALOGUE_PATH = getattr(settings, 'MEDIALOGUE_PATH', None)
if MEDIALOGUE_PATH is not None:
    if callable(MEDIALOGUE_PATH):
        get_storage_path = MEDIALOGUE_PATH
    else:
        parts = MEDIALOGUE_PATH.split('.')
        module_name = '.'.join(parts[:-1])
        module = import_module(module_name)
        get_storage_path = getattr(module, parts[-1])
else:
    def get_storage_path(instance, filename):
        fn = unicodedata.normalize('NFKD', force_str(filename)).encode('ascii', 'ignore').decode('ascii')
        return os.path.join(MEDIALOGUE_DIR, '', fn)

# Exif Orientation values
# Value 0thRow	0thColumn
#   1	top     left
#   2	top     right
#   3	bottom	right
#   4	bottom	left
#   5	left	top
#   6	right   top
#   7	right   bottom
#   8	left    bottom

# Image Orientations (according to EXIF informations) that needs to be
# transposed and appropriate action
IMAGE_EXIF_ORIENTATION_MAP = {
    2: Image.FLIP_LEFT_RIGHT,
    3: Image.ROTATE_180,
    6: Image.ROTATE_270,
    8: Image.ROTATE_90,
}

# Quality options for JPEG images
JPEG_QUALITY_CHOICES = (
    (30, _('Very Low')),
    (40, _('Low')),
    (50, _('Medium-Low')),
    (60, _('Medium')),
    (70, _('Medium-High')),
    (80, _('High')),
    (90, _('Very High')),
)

class SharedQueries(OrderedModelQuerySet):
    def on_site(self):
        """Return objects linked to the current site only."""
        return self.filter(sites__id=settings.SITE_ID)
    def is_public(self):
        return self.filter(is_public=True)
class MedialogueQueryManager(models.Manager.from_queryset(SharedQueries)):
    pass


class Album(models.Model):
    objects = SharedQueries.as_manager()
    date_added = models.DateTimeField(_('date published'), default=now)
    title = models.CharField(
        _('title'),
        max_length=250,
        unique=True,
    )
    slug = models.SlugField(
        _('title slug'),
        unique=True,
        max_length=250,
    )
    description = models.TextField(_('description'), blank=True)
    is_public = models.BooleanField(
        _('is public'),
        default=True,
    )
    sites = models.ManyToManyField(
        Site,
        verbose_name=_('sites'),
        blank=True
    )

    class Meta:
        ordering = ['-date_added']
        get_latest_by = 'date_added'
        verbose_name = _('Album')
        verbose_name_plural = _('Albums')

    def __str__(self):
        return self.title

    def latest(self, limit=LATEST_LIMIT, public=True):
        if not limit:
            limit = self.media_count()
            if public:
                return self.public()[:limit]
            else:
                return self.media.filter(sites__id=settings.SITE_ID)[:limit]

    def public(self):
        """Return a queryset of all the public media in this album."""
        return self.media.is_public().filter(sites__id=settings.SITE_ID)

    def sample(self, count=None, public=True):
        """Return a sample of media, ordered at random.
        If the 'count' is not specified, it will return a number of media
        limited by the GALLERY_SAMPLE_SIZE setting.
        """
        if not count:
            count = SAMPLE_SIZE
            if count > self.photo_count():
                count = self.photo_count()
                if public:
                    photo_set = self.public()
                else:
                    photo_set = self.media.filter(sites__id=settings.SITE_ID)
                    return random.sample(set(photo_set), count)

    def media_count(self, public=True):
        """Return a count of all the media in this album."""
        if public:
            return self.public().count()
        else:
            return self.media.filter(sites__id=settings.SITE_ID).count()

    media_count.short_description = _('count')

    def public(self):
        """Return a queryset of all the public media in this album."""
        return self.media.is_public().filter(sites__id=settings.SITE_ID)

    def get_absolute_url(self):
        return reverse('medialogue:ml-album', args=[self.slug])
class Media(OrderedModel):
    objects = SharedQueries.as_manager()
    album = models.ForeignKey(Album, related_name="media", on_delete=models.CASCADE)
    order_with_respect_to = 'album'

    date_taken = models.DateTimeField(
        _('date taken'),
        null=True,
        blank=True,
    )
    title = models.CharField(
        _('title'),
        max_length=250,
        unique=True,
    )
    slug = models.SlugField(
        _('slug'),
        unique=True,
        max_length=250,
    )
    caption = models.TextField(_('caption'), blank=True)
    date_added = models.DateTimeField(_('date added'), default=now)
    is_public = models.BooleanField(
        _('is public'),
        default=True,
    )

    sites = models.ManyToManyField(
        Site,
        verbose_name=_('sites'),
        blank=True,
    )

    def get_previous_in_album(self, album):
        """Find the neighbour of this media object in the supplied album.
        We assume that the album and all its objects are on the same site.
        """
        if not self.is_public:
            raise ValueError('Cannot determine neighbours of a non-public media.')
        media = album.media.is_public()

        # TODO - issues with Photo/Video/Media objects.  self will look like Photo(I) while 
        # The media queryset will look like [Media(I)]
        #if self not in media:
        #    raise ValueError('media does not belong to album.')

        previous = None
        for m in media:
            if m.id == self.id:
                return previous
            previous = m

    def get_next_in_album(self, album):
        """Find the neighbour of this media object in the supplied album.
        We assume that the album and all its objects are on the same site.
        """
        if not self.is_public:
            raise ValueError('Cannot determine neighbours of a non-public media.')
        media = album.media.is_public()
        matched = False

        for m in media:
            if matched:
                return m
            if m.id == self.id:
                matched = True
        return None


class Photo(Media):
    objects = SharedQueries.as_manager()
    src = models.ImageField(
        _('src'),
        max_length=IMAGE_FIELD_MAX_LENGTH,
        upload_to=get_storage_path,
    )

    def EXIF(self, file=None):
        try:
            if file:
                tags = exifread.process_file(file)
            else:
                with self.src.storage.open(self.src.name, 'rb') as file:
                    tags = exifread.process_file(file, details=False)
            return tags
        except:
            return {}

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self._old_src = self.src

    def get_absolute_url(self):
        return reverse('medialogue:ml-photo', args=[self.slug])

    def save(self, *args, **kwargs):
        image_has_changed = False
        if self._get_pk_val() and (self._old_src != self.src):
            image_has_changed = True
            self._old_src.storage.delete(self._old_src.name)  # Delete (old) base image.

        if self.date_taken is None or image_has_changed:
            # Attempt to get the date the photo was taken from the EXIF data.
            try:
                exif_date = self.EXIF(self.src.file).get('EXIF DateTimeOriginal', None)
                if exif_date is not None:
                    d, t = exif_date.values.split()
                    year, month, day = d.split(':')
                    hour, minute, second = t.split(':')
                    self.date_taken = datetime(int(year), int(month), int(day),
                                               int(hour), int(minute), int(second))
            except:
                logger.error('Failed to read EXIF DateTimeOriginal', exc_info=True)
        super().save(*args, **kwargs)

class Video(Media):
    """
    NOTE -  Calls post_save connected in apps.py/signals.py
    - medialogue.tasks.create_thumbnail 
    - django_video_encoding.tasks.convert_all_videos
    """
    objects = SharedQueries.as_manager()
    thumbnail = models.ImageField(blank=True)
    format_set = GenericRelation(Format)
    # video detail fields
    width = models.PositiveIntegerField(editable=False, null=True)
    height = models.PositiveIntegerField(editable=False, null=True)
    duration = models.FloatField(editable=False, null=True)
    src = VideoField(
        width_field='width',
        height_field='height',
        duration_field='duration'
    )

    def get_absolute_url(self):
        return reverse("medialogue:ml-video", args=[self.slug])

    def __str__(self):
        return self.title



def add_default_site(instance, created, **kwargs):
    """
    Called via Django's signals when an instance is created.
    In case PHOTOLOGUE_MULTISITE is False, the current site (i.e.
    ``settings.SITE_ID``) will always be added to the site relations if none are
    present.
    """
    if not created:
        return
    if getattr(settings, 'MEDIALOGUE_MULTISITE', False):
        return
    if instance.sites.exists():
        return
    instance.sites.add(Site.objects.get_current())


post_save.connect(add_default_site, sender=Album)
post_save.connect(add_default_site, sender=Video)
post_save.connect(add_default_site, sender=Photo)



from django.urls import path, include, re_path, reverse_lazy
from .views import *
from django.views.generic import RedirectView

app_name = 'medialogue'
urlpatterns = [
        path('',
            RedirectView.as_view(
                url=reverse_lazy('medialogue:ml-album-list'), 
                permanent=True
            ),
            name='ml-medialogue-root'
        ),
	path('api/', include('medialogue.api.urls')),
	path('albums/', AlbumListView.as_view(), name='ml-album-list'),
        path('album/new/', NewAlbum, name='new-album'),
        re_path('album/(?P<slug>[\-\d\w]+)/edit/$', AlbumEditView, name='ml-album-edit'),
        re_path('album/(?P<slug>[\-\d\w]+)/$', AlbumDetailView.as_view(), name='ml-album'),
        re_path('video/(?P<slug>[\-\d\w]+)/$', VideoDetailView.as_view(), name='ml-video'),
        path('photos/', PhotoListView.as_view(), name='ml-photo-list'),
        path('videos/', VideoListView.as_view(), name='ml-video-list'),
        re_path('^photo/(?P<slug>[\-\d\w]+)/$', PhotoDetailView.as_view(), name='ml-photo'),
        path('fp/', include('django_drf_filepond.urls')),
]



from django.contrib import admin
from .models import Album, Video, Photo

from video_encoding.admin import FormatInline

@admin.register(Video)
class VideoAdmin(admin.ModelAdmin):
   inlines = (FormatInline,)

@admin.register(Album)
class AlbumAdmin(admin.ModelAdmin):
    pass

@admin.register(Photo)
class PhotoAdmin(admin.ModelAdmin):
   inlines = (FormatInline,)



from django.apps import AppConfig

class AntiTimelineConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'medialogue'

    def ready(self):
        import medialogue.signals



import os
from setuptools import setup, find_packages
from pkg_resources import parse_requirements

version = "2.0.2"

def get_requirements(source):
    with open(source) as f:
        return sorted({str(req) for req in parse_requirements(f.read())})

# Lovingly stolen from https://tinyurl.com/2fwt4c99
def package_files(directory):
    paths = []
    for (path, directories, filenames) in os.walk(directory):
        for filename in filenames:
            paths.append(os.path.join('..', path, filename))
    return paths

package_data = package_files('medialogue/migrations') + package_files('medialogue/templates') + package_files('medialogue/static') + package_files('medialogue/templatetags')

setup(
    name='django-medialogue',
    author='Derek Adair',
    author_email='d@derekadair.comm',
    version=version,
    description='An Fork of django-medialogue with video support',
    zip_safe=False,
    classifiers=['Development Status :: 5 - Production/Stable',
                 'Environment :: Web Environment',
                 'Framework :: Django',
                 'Intended Audience :: Developers',
                 'License :: OSI Approved :: BSD License',
                 'Operating System :: OS Independent',
                 'Programming Language :: Python',
                 'Programming Language :: Python :: 3',
                 'Programming Language :: Python :: 3.4',
                 'Programming Language :: Python :: 3.5',
                 'Programming Language :: Python :: 3.6',
                 'Topic :: Utilities'],
    packages=['medialogue'],
    include_package_data=True,
    package_data= {
            '': package_data,
        },
    install_requires=get_requirements('build-requirements.txt'),
    url="https://github.com/derek-adair/medialogue",
    )



from django.core.files import File
from video_encoding.backends import get_backend
import os

import logging
logger = logging.getLogger(__name__)

from .models import Video

def create_thumbnail(video_pk):
    logger.info("create_thumbnail task called")
    video = Video.objects.get(pk=video_pk)
    if not video.src:
        # no video file attached
        return

    if video.thumbnail:
        # thumbnail has already been generated
        return

    encoding_backend = get_backend()
    thumbnail_path = encoding_backend.get_thumbnail(video.src.path)
    filename = os.path.basename(thumbnail_path)

    try:
        with open(thumbnail_path, 'rb') as file_handler:
            django_file = File(file_handler)
            video.thumbnail.save(filename, django_file)
        video.save()
    finally:
        os.unlink(thumbnail_path)
